#include "mainwindow.h"
#include "drawwidget.h"
#include "ui_mainwindow.h"
#include "simulationdialog.h"
#include "simulation.h"
#include <iostream>
#include <chrono>
#include <QTimer>

MainWindow::MainWindow(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::MainWindow),
    m_simSpeed(500)
{
    ui->setupUi(this);
    connect(ui->startButton, SIGNAL(pressed()), this, SLOT(openSimuDialog()));
}

MainWindow::~MainWindow()
{
    delete ui;
}

void MainWindow::openSimuDialog()
{
    SimulationDialog *dialog = new SimulationDialog(this);
    dialog->setWindowTitle("Starting a new Simulation");
    connect(dialog, SIGNAL(sendError(QString, int)), ui->statusBar, SLOT(showMessage(QString, int)));
    int ret = dialog->exec();
    if(ret == QDialog::Accepted)
    {
        p_simu = dialog->getSimulation();
        ui->drawWidget->startSimulation(p_simu->getMap());
        QTimer *timer = new QTimer(this);
        connect(timer,SIGNAL(timeout()),this, SLOT(updateSimu()));
        timer->start(m_simSpeed);
        m_date = 0;
    }
}

void MainWindow::updateSimu()
{
    p_simu->update();
    ui->dateLabel->setText(QString::number(++m_date));
    ui->drawWidget->updateDudesBehavior();
    ui->drawWidget->repaint();
}
